@@ -94,18 +94,12 @@ int main(int argc, char *argv[])
 	sprintf(Config.Bios, "/scph1001.bin");
 	
 	strcpy(Config.Net, _("Disabled"));
-#ifdef IPHONE
-	ChangeWorkingDirectory(get_documents_path("psx4iphone"));
-#else
-#ifndef MAEMO_CHANGES
-	ChangeWorkingDirectory(argv[0]);
-#endif
-#endif
-#ifdef ROM_PREFIX
-	strncpy(gamepath,ROM_PREFIX,1024);
-#else
-	getcwd(gamepath, 1024);
-#endif
+
+
+	ChangeWorkingDirectory("/home/user");
+
+	strncpy(gamepath,"/home/user/MyDocs",1024);
+
 	sprintf(Config.BiosDir, "%s", gamepath);
 #ifdef DATA_PREFIX
 	sprintf(Config.Mcd1, "%s/mcd001.mcr", DATA_PREFIX);
