@@ -134,29 +134,28 @@ void hildon_init(int *argc, char ***argv,char *fl,char* lst,bool fscreen)
 {
 fullscreen=fscreen;
 	file=fl;
+	cfile=new char[255];
+	sprintf (cfile, "%s.save.%s", file,lst);
+	if (Config.PsxOut)printf ("Save file:%s\n",cfile);
+	//cfile="/home/opt/psx4m/savestate";
 	
-	sprintf (cfile, "%s.save-%s", file,lst);
 	
-	loadst=lst;
 
 	// read key config
 	FILE* pFile;
-	pFile = fopen("/home/opt/psx4m/keys", "r"); // assume the file exists and has data
+	pFile = fopen("/opt/psx4m/keys", "r"); // assume the file exists and has data
 	int ch;
 	for (int i=0;i<65536;i++)
-		keymap[i]=0;
+		keymap[i]=164;
 	if (NULL != pFile) {
 		for(int i=0;i<21;i++){
-		try{
 			fscanf(pFile, "%i",&ch);
 			keymap[ch]=i;
-			}catch(int e){
-			keymap[i]=164;
-			}
 		}
 		fclose(pFile);
 	}
 
+	
 	gtk_init (argc, argv);
 	window = hildon_stackable_window_new ();
 	gtk_widget_realize (window);
